@@ -5,10 +5,12 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 #
-# Author: Kyle Lahnakoski (kyle@lahnakoski.com)
+# Contact: Kyle Lahnakoski (kyle@lahnakoski.com)
 #
 from __future__ import absolute_import, division, unicode_literals
 
+from jx_base.expressions import Variable
+from jx_base.language import is_op
 from mo_future import is_text, is_binary
 from copy import copy
 
@@ -19,7 +21,7 @@ from jx_python.containers import Container
 from jx_python.expressions import TRUE
 from jx_python.namespace import Namespace, convert_list
 from mo_dots import Data, FlatList, Null, coalesce, is_data, is_list, listwrap, wrap
-from mo_future import text_type
+from mo_future import text
 from mo_logs import Log
 import mo_math
 
@@ -75,8 +77,6 @@ class Normal(Namespace):
         if not mo_math.is_integer(output.limit) or output.limit < 0:
             Log.error("Expecting limit >= 0")
 
-        output.isLean = query.isLean
-
         # DEPTH ANALYSIS - LOOK FOR COLUMN REFERENCES THAT MAY BE DEEPER THAN
         # THE from SOURCE IS.
         vars = get_all_vars(output, exclude_where=True)  # WE WILL EXCLUDE where VARIABLES
@@ -84,8 +84,6 @@ class Normal(Namespace):
             if c.name in vars and len(c.nested_path) != 1:
                 Log.error("This query, with variable {{var_name}} is too deep", var_name=c.name)
 
-        output.having = convert_list(self._convert_having, query.having)
-
         return output
 
     def _convert_from(self, frum):
